<?php

namespace Justlab\JLToken\Controllers;

use Justlab\JLToken\Constant;
use Justlab\JLToken\Flash;
use Justlab\JLToken\Models\CallStatus;
use Justlab\JLToken\Models\Setting;
use Justlab\JLToken\Models\Voice;
use Justlab\JLToken\Utility;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class ActivationController extends Controller
{
    public static function activate($db = false)
    {
        if ($db) {
            require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

            global $wpdb;

            $charset_collate = $wpdb->get_charset_collate();

            dbDelta(
                [
                    "CREATE TABLE " . $wpdb->prefix . "jltoken_services (
                    id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
                    name varchar(60) NOT NULL,
                    letter varchar(60) NOT NULL,
                    start_number mediumint(9) NOT NULL,
                    ask_name tinyint(1) NOT NULL DEFAULT 0,
                    ask_email tinyint(1) NOT NULL DEFAULT 0,
                    ask_phone tinyint(1) NOT NULL DEFAULT 0,
                    name_required tinyint(1) NOT NULL DEFAULT 0,
                    email_required tinyint(1) NOT NULL DEFAULT 0,
                    phone_required tinyint(1) NOT NULL DEFAULT 0,
                    status tinyint(1) NOT NULL,
                    created_at timestamp NULL,
                    updated_at timestamp NULL,
                    PRIMARY KEY  (id)
                    ) $charset_collate;",

                    "CREATE TABLE " . $wpdb->prefix . "jltoken_counters (
                    id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
                    name varchar(60) NOT NULL,
                    status tinyint(1) NOT NULL,
                    created_at timestamp NULL,
                    updated_at timestamp NULL,
                    PRIMARY KEY  (id)
                    ) $charset_collate;",

                    "CREATE TABLE " . $wpdb->prefix . "jltoken_queues (
                    id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
                    service_id bigint(20) unsigned NOT NULL,
                    reference_no varchar(60) NOT NULL,
                    letter varchar(60) NOT NULL,
                    number mediumint(9) NOT NULL,
                    called tinyint(1) NOT NULL,
                    position int(11) unsigned NOT NULL,
                    name varchar(60) NULL,
                    email varchar(60) NULL,
                    phone varchar(60) NULL,
                    created_at timestamp NULL,
                    updated_at timestamp NULL,
                    PRIMARY KEY  (id),
                    FOREIGN KEY  jltoken_queues_service_id_foreign (service_id) REFERENCES " . $wpdb->prefix . "jltoken_services (id)
                    ) $charset_collate;",

                    "CREATE TABLE " . $wpdb->prefix . "jltoken_call_statuses (
                    id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
                    name varchar(60) NOT NULL,
                    PRIMARY KEY  (id)
                    ) $charset_collate;",

                    "CREATE TABLE " . $wpdb->prefix . "jltoken_calls (
                    id bigint(20) unsigned NOT NULL AUTO_INCREMENT, 
                    queue_id bigint(20) unsigned NOT NULL,
                    service_id bigint(20) unsigned NOT NULL,
                    counter_id bigint(20) unsigned NOT NULL,
                    user_id bigint(20) unsigned NOT NULL,
                    call_status_id bigint(20) unsigned NULL,
                    letter varchar(60) NOT NULL,
                    number mediumint(9) NOT NULL,
                    called_date date NOT NULL,
                    started_at timestamp NOT NULL,
                    ended_at timestamp NULL,
                    waiting_time time NULL,
                    served_time time NULL,
                    turn_around_time time NULL,
                    created_at timestamp NULL,
                    updated_at timestamp NULL,
                    PRIMARY KEY  (id),
                    FOREIGN KEY  jltoken_calls_queue_id_foreign (queue_id) REFERENCES " . $wpdb->prefix . "jltoken_queues (id) ON DELETE CASCADE,
                    FOREIGN KEY  jltoken_calls_service_id_foreign (service_id) REFERENCES " . $wpdb->prefix . "jltoken_services (id) ON DELETE CASCADE,
                    FOREIGN KEY  jltoken_calls_counter_id_foreign (counter_id) REFERENCES " . $wpdb->prefix . "jltoken_counters (id) ON DELETE CASCADE,
                    FOREIGN KEY  jltoken_calls_user_id_foreign (user_id) REFERENCES " . $wpdb->prefix . "users (ID),
                    FOREIGN KEY  jltoken_calls_call_status_id_foreign (call_status_id) REFERENCES " . $wpdb->prefix . "jltoken_call_statuses (id)
                    ) $charset_collate;",

                    "CREATE TABLE " . $wpdb->prefix . "jltoken_voices (
                    id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
                    name varchar(60) NOT NULL,
                    native_name varchar(60) NOT NULL,
                    code varchar(60) NOT NULL,
                    voice varchar(60) NOT NULL,
                    token_trans text NOT NULL,
                    please_proceed_to_trans text NOT NULL,
                    PRIMARY KEY  (id)
                    ) $charset_collate;",

                    "CREATE TABLE " . $wpdb->prefix . "jltoken_settings (
                    id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
                    voice_id bigint(20) unsigned NOT NULL,
                    notification text NULL,
                    font_size int(11) NULL,
                    font_color varchar(60) NULL,
                    show_on_display varchar(60) NULL,
                    installed int(11) unsigned NOT NULL,
                    PRIMARY KEY  (id),
                    FOREIGN KEY  jltoken_voice_id_foreign (voice_id) REFERENCES " . $wpdb->prefix . "jltoken_voices (id)
                    ) $charset_collate;",
                ]
            );

            self::dbSeed();
            self::generateRewriteRules();
            flush_rewrite_rules(false);
        }

        self::setVer();
    }

    public static function deactivate()
    {
        Flash::cleanUpFlashMessages();
        self::clearSession();
        self::setVer(true);
        flush_rewrite_rules(false);
    }

    public static function complete($from_update = false)
    {
        if (!$from_update) {
            check_ajax_referer('jltoken_complete');
        }

        self::activate(true);

        $settings = Setting::find(1);
        if ($settings) {
            Utility::deleteDir(JLTOKEN__PLUGIN_DIR . 'views/admin/' . base64_decode('aW5zdGFsbA=='));
            Utility::deleteDir(JLTOKEN__PLUGIN_DIR . 'assets/css/' . base64_decode('aW5zdGFsbA=='));
            Utility::createDir(JLTOKEN__PLUGIN_DIR . 'assets/files');

            $col = base64_decode(Constant::KEY);
            $settings->$col = base64_decode('Mg==');
            $settings->save();

            if (!$from_update) {
                wp_send_json(['status' => true]);
            }
        }
        if (!$from_update) {
            wp_send_json(['status' => false], 500);
        }
    }

    public static function dbSeed()
    {
        // Call Statuses
        if (!CallStatus::find(1)) {
            CallStatus::insert(['id' => 1, 'name' => 'served']);
        }
        if (!CallStatus::find(2)) {
            CallStatus::insert(['id' => 2, 'name' => 'noshow']);
        }

        // Voices
        $voices = [
            ['id' => 1, 'name' => 'English', 'native_name' => 'English', 'code' => 'en', 'voice' => 'US English Female', 'token_trans' => 'Token', 'please_proceed_to_trans' => 'Please Proceed To'],
            ['id' => 2, 'name' => 'French', 'native_name' => 'Français', 'code' => 'fr', 'voice' => 'French Female', 'token_trans' => 'Jeton', 'please_proceed_to_trans' => 'Veuillez passer à'],
            ['id' => 3, 'name' => 'Hindi', 'native_name' => 'हिन्दी', 'code' => 'hi', 'voice' => 'Hindi Female', 'token_trans' => 'टोकन', 'please_proceed_to_trans' => 'कृपया आगे बढ़ें'],
            ['id' => 4, 'name' => 'Arabic', 'native_name' => 'عربي', 'code' => 'ar', 'voice' => 'Arabic Male', 'token_trans' => 'رمز', 'please_proceed_to_trans' => 'يرجى المتابعة إلى'],
            ['id' => 5, 'name' => 'Spanish', 'native_name' => 'Español', 'code' => 'es', 'voice' => 'Spanish Female', 'token_trans' => 'simbólico', 'please_proceed_to_trans' => 'por favor proceda a'],
            ['id' => 6, 'name' => 'Portuguese', 'native_name' => 'Português', 'code' => 'pt', 'voice' => 'Portuguese Female', 'token_trans' => 'símbolo', 'please_proceed_to_trans' => 'Por favor, prossiga para'],
            ['id' => 7, 'name' => 'Italian', 'native_name' => 'Italiano', 'code' => 'it', 'voice' => 'Italian Female', 'token_trans' => 'gettone', 'please_proceed_to_trans' => 'si prega di procedere a'],
            ['id' => 8, 'name' => 'Indonesian', 'native_name' => 'Indonesian', 'code' => 'id', 'voice' => 'Indonesian Female', 'token_trans' => 'token', 'please_proceed_to_trans' => 'silakan lanjutkan ke'],
        ];
        foreach ($voices as $voice) {
            $data =  Voice::find($voice['id']);
            if ($data) {
                $data->name = $voice['name'];
                $data->native_name = $voice['native_name'];
                $data->code = $voice['code'];
                $data->voice = $voice['voice'];
                $data->token_trans = $voice['token_trans'];
                $data->please_proceed_to_trans = $voice['please_proceed_to_trans'];
                $data->save();
            } else {
                Voice::insert($voice);
            }
        }

        // Settings
        if (!Setting::find(1)) {
            $settings = ['voice_id' => 1, 'notification' => 'Welcome to JL Token', 'font_size' => 40, 'font_color' => '#000', 'installed' => 0];
            Setting::insert($settings);
        }
    }

    public static function setVer($remove = false)
    {
        if ($remove) {
            delete_option(Constant::VER);
            return;
        }

        if (get_option(Constant::VER)) {
            update_option(Constant::VER, JLTOKEN_VERSION);
            return;
        }
        add_option(Constant::VER, JLTOKEN_VERSION);
    }

    public static function generateRewriteRules()
    {
        add_filter('generate_rewrite_rules', function ($wp_rewrite) {
            $wp_rewrite->rules = array_merge(
                ['jltoken-kiosk/?$' => 'index.php?jltoken-kiosk=1'],
                ['jltoken-display/?$' => 'index.php?jltoken-display=1'],
                $wp_rewrite->rules
            );
        });
    }

    public static function clearSession()
    {
        $session_keys = ['jltoken_service', 'jltoken_counter'];
        foreach ($session_keys as $session) {
            if (isset($_SESSION[$session])) {
                unset($_SESSION[$session]);
            }
        }
    }
}
