<?php

namespace Justlab\JLToken\Controllers;

use IgniteKit\Validation\ErrorBag;
use Justlab\JLToken\DB;
use Justlab\JLToken\Models\Counter;
use Justlab\JLToken\Repositories\CounterRepository;
use Justlab\JLToken\Validator\Validator;
use Throwable;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class CounterController extends Controller
{
    const VIEW_DIR = JLTOKEN__PLUGIN_DIR . 'views/admin/counters/';

    private static $initiated = false;

    public static function init()
    {
        if (!self::$initiated) {
            self::initHooks();
        }
    }

    public static function initHooks()
    {
        self::$initiated = true;

        add_submenu_page('jltoken', esc_html__('Counters', 'jltoken') . ' | JL Token', esc_html__('Counters', 'jltoken'), 'manage_options', 'jltoken-counters', [self::class, 'findPage'], 3);
    }

    public static function findPage()
    {
        self::counter();

        $view = isset($_GET['view']) ? trim($_GET['view']) : '';

        switch ($view) {
            case '':
            case 'list':
                self::listView();
                break;
            case 'create':
                if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                    $result = self::store();
                }
                self::create($result);
                break;
            case 'edit':
                if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                    $result = self::update();
                }
                self::edit($result);
                break;
            default:
                self::listView();
        }
    }

    public static function listView()
    {
        self::counter();

        ob_start();

        include_once(self::VIEW_DIR . 'list.php');

        $view = ob_get_contents();

        ob_end_clean();

        echo $view;
    }

    public static function create($result)
    {
        self::counter();

        if ($result instanceof ErrorBag) {
            $errors = $result;
            unset($result);
        }

        ob_start();

        include_once(self::VIEW_DIR . 'form.php');

        $view = ob_get_contents();

        ob_end_clean();

        echo $view;
    }

    public static function store()
    {
        self::counter();

        check_admin_referer('jltoken-counters-create');

        $data = [];

        $data['name'] = isset($_POST['name']) ? trim($_POST['name']) : '';
        $data['status'] = isset($_POST['status']) ? trim($_POST['status']) : '';

        $validator = new Validator;

        $validation = $validator->validate($data, [
            'name' => 'required|max:60|unique:counters,name',
            'status' => 'required|in:1,0',
        ]);

        if ($validation->fails()) {
            return $validation->errors();
        }

        DB::beginTransaction();
        try {
            $counter = CounterRepository::create($data);
        } catch (Throwable $th) {
            DB::rollback();

            return 0;
        }
        DB::commit();

        return $counter;
    }

    public static function edit($result)
    {
        self::counter();

        $counter_id = isset($_GET['id']) ? trim($_GET['id']) : '';
        $counter = Counter::find($counter_id);

        if ($result instanceof ErrorBag) {
            $errors = $result;
            unset($result);
        }

        ob_start();

        include_once(self::VIEW_DIR . 'form.php');

        $view = ob_get_contents();

        ob_end_clean();

        echo $view;
    }

    public static function update()
    {
        self::counter();

        check_admin_referer('jltoken-counters-edit');

        $data = [];

        $data['id'] = isset($_POST['id']) ? trim($_POST['id']) : '';
        $data['name'] = isset($_POST['name']) ? trim($_POST['name']) : '';
        $data['status'] = isset($_POST['status']) ? trim($_POST['status']) : '';

        $validator = new Validator;
        $validation = $validator->validate($data, [
            'id' => 'required|integer|exists:counters,id',
            'name' => 'required|max:60|unique:counters,name,' . $data['id'],
            'status' => 'required|in:1,0',
        ]);

        if ($validation->fails()) {
            return $validation->errors();
        }

        DB::beginTransaction();
        try {
            $counter = Counter::find($data['id']);
            $counter = CounterRepository::update($counter, $data);
        } catch (Throwable $th) {
            DB::rollback();

            return 0;
        }
        DB::commit();

        return $counter;
    }
}
