<?php

namespace Justlab\JLToken\Controllers\Front;

use IgniteKit\Validation\ErrorBag;
use Justlab\JLToken\Controllers\Controller;
use Justlab\JLToken\Flash;
use Justlab\JLToken\Models\Service;
use Justlab\JLToken\Repositories\ServiceRepository;
use Justlab\JLToken\Repositories\TokenRepository;
use Justlab\JLToken\Validator\Validator;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class KioskController extends Controller
{
    public static function base()
    {
        self::kiosk();

        self::index();
    }

    public static function index()
    {
        self::kiosk();

        $services = ServiceRepository::getActiveServices();

        include JLTOKEN__PLUGIN_DIR . 'views/front/kiosk.php';
    }

    public static function createToken()
    {
        self::kiosk();

        check_ajax_referer('jltoken_create_token');

        $data = [];
        $data['service_id'] = isset($_POST['service_id']) ? trim($_POST['service_id']) : '';
        $data['with_details'] = isset($_POST['with_details']) ? filter_var(trim($_POST['with_details']), FILTER_VALIDATE_BOOLEAN) : '';
        $data['name'] = isset($_POST['name']) ? trim($_POST['name']) : '';
        $data['email'] = isset($_POST['email']) ? trim($_POST['email']) : '';
        $data['phone'] = isset($_POST['phone']) ? trim($_POST['phone']) : '';

        $service = Service::find($data['service_id']);

        $validator = new Validator;
        $validation = $validator->validate($data, [
            'service_id' => 'required|integer|exists:services,id',
            'with_details' => 'required|boolean',
            'name' => [function ($value) use ($data, $service) {
                if ($data['with_details'] && $service->name_required) {
                    if (!$value) return esc_html__('Name is required', 'jltoken');
                }
            }],
            'email' => [function ($value) use ($data, $service) {
                if ($data['with_details'] && $service->email_required) {
                    if (!$value) return esc_html__('Email is required', 'jltoken');
                }
            }, 'email'],
            'phone' => [function ($value) use ($data, $service) {
                if ($data['with_details'] && $service->phone_required) {
                    if (!$value) return esc_html__('Phone is required', 'jltoken');
                }
            }],
        ]);

        if ($validation->fails()) {
            wp_send_json($validation->errors()->toArray(), 422);
        }

        $queue = TokenRepository::createToken($service, $data);

        TokenRepository::setTokensOnFile();
        $count = TokenRepository::customerWaiting($service);

        wp_send_json(['queue' => $queue, 'service' => $service, 'waiting' => ($count > 0 ?  $count - 1 : $count)]);
    }
}
