<?php

namespace Justlab\JLToken\Controllers;

use Justlab\JLToken\Constant;
use Justlab\JLToken\Controllers\Front\DisplayController;
use Justlab\JLToken\Controllers\Front\KioskController;
use Justlab\JLToken\Flash;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class InitController extends Controller
{
    private static $initiated = false;

    public static function init()
    {
        if (!self::$initiated) {
            self::initHooks();
        }
    }

    public static function initHooks()
    {
        self::$initiated = true;

        Flash::init();

        if (self::$ok) {
            add_filter('query_vars', [self::class, 'queryVars']);
            add_action('template_redirect', [self::class, 'templateRedirect']);
        }

        if (self::$ok) {
            // Updating
            if (version_compare(get_option(Constant::VER), JLTOKEN_VERSION, '<')) {
                ActivationController::complete(true);
            }

            ActivationController::generateRewriteRules();
        }
        self::registerRoutes();

        self::initActions();

        // Only inside JLToken pages
        if (isset($_GET['page']) && str_contains($_GET['page'], 'jltoken')) {
            self::registerStyle();
            self::registerScript();

            wp_enqueue_style('jltoken');
            wp_enqueue_script('jltoken');

            add_filter('admin_footer_text', [self::class, 'footerText'], 1000);
            add_filter('update_footer', [self::class, 'footerVerText'], 1000);
        }
    }

    public static function initActions()
    {
        load_plugin_textdomain('jltoken', false, str_replace(str_replace('\\', '/', WP_PLUGIN_DIR), '', (str_replace('\\', '/', JLTOKEN__PLUGIN_DIR) . 'lang')));
        add_action('admin_menu', [self::class, 'initMenu']);
        add_action('wp_logout', [ActivationController::class, 'clearSession']);
    }

    public static function initMenu()
    {
        add_menu_page('JL Token', 'JL Token', 'manage_options', 'jltoken', [DashboardController::class, self::$ok ? 'dashboardView' : 'initAll'], plugins_url('assets/img/icon.png', JLTOKEN__PLUGIN_URL), 40);
        if (self::$ok) {
            DashboardController::init();
            CallController::init();
            ServiceController::init();
            CounterController::init();
            ReportController::init();
            SettingController::init();
        }
    }

    public static function queryVars($query_vars)
    {
        $query_vars[] = 'jltoken-kiosk';
        $query_vars[] = 'jltoken-display';
        return $query_vars;
    }

    public static function templateRedirect()
    {
        $kiosk = intval(get_query_var('jltoken-kiosk'));
        $display = intval(get_query_var('jltoken-display'));

        if ($kiosk) {
            KioskController::base();
            die;
        } else if ($display) {
            DisplayController::index();
            die;
        }
    }

    public static function registerStyle()
    {
        wp_register_style('jltoken', plugins_url('assets/css/jltoken.css', JLTOKEN__PLUGIN_URL), [],  JLTOKEN_VERSION, 'all');
        wp_register_style('jltoken-materialize', plugins_url('assets/css/materialize.min.css', JLTOKEN__PLUGIN_URL), [],  JLTOKEN_VERSION, 'all');
        wp_register_style('jltoken-style', plugins_url('assets/css/style.min.css', JLTOKEN__PLUGIN_URL), [],  JLTOKEN_VERSION, 'all');
        wp_register_style('jltoken-main', plugins_url('assets/css/main.css', JLTOKEN__PLUGIN_URL), [],  JLTOKEN_VERSION, 'all');
        wp_register_style('jltoken-normalize', plugins_url('assets/css/normalize.min.css', JLTOKEN__PLUGIN_URL), [],  JLTOKEN_VERSION, 'all');
        wp_register_style('jltoken-app', plugins_url('assets/css/jltoken-app.css', JLTOKEN__PLUGIN_URL), [],  JLTOKEN_VERSION, 'all');
        wp_register_style('jltoken-datatable', plugins_url('assets/css/dataTables.min.css', JLTOKEN__PLUGIN_URL), [],  JLTOKEN_VERSION, 'all');
        wp_register_style('jltoken-inst-styles', plugins_url('assets/css/install/style.min.css', JLTOKEN__PLUGIN_URL), [],  JLTOKEN_VERSION, 'all');
    }

    public static function registerScript()
    {
        wp_register_script('jltoken', plugins_url('assets/js/jltoken.js', JLTOKEN__PLUGIN_URL), ['jquery'],  JLTOKEN_VERSION, true);
        wp_register_script('jltoken-vendor', plugins_url('assets/js/vendor.min.js', JLTOKEN__PLUGIN_URL), ['jquery'],  JLTOKEN_VERSION, true);
        wp_register_script('jltoken-app', plugins_url('assets/js/jltoken-app.js', JLTOKEN__PLUGIN_URL), ['jquery'],  JLTOKEN_VERSION, true);
        wp_register_script('jltoken-datatable', plugins_url('assets/js/dataTables.min.js', JLTOKEN__PLUGIN_URL), ['jquery'],  JLTOKEN_VERSION, true);
        wp_register_script('jltoken-validate', plugins_url('assets/js/validate.min.js', JLTOKEN__PLUGIN_URL), ['jquery'],  JLTOKEN_VERSION, true);
        wp_register_script('jltoken-reports', plugins_url('assets/js/reports.js', JLTOKEN__PLUGIN_URL), ['jquery'],  JLTOKEN_VERSION, true);
        wp_register_script('jltoken-chart', plugins_url('assets/js/chart.min.js', JLTOKEN__PLUGIN_URL), ['jquery'],  JLTOKEN_VERSION, true);
        wp_register_script('jltoken-dashboard', plugins_url('assets/js/dashboard.js', JLTOKEN__PLUGIN_URL), ['jquery'],  JLTOKEN_VERSION, true);
    }

    public static function registerRoutes()
    {
        if (wp_doing_ajax()) {
            if (!self::$ok) {
                add_action('wp_ajax_jltoken_complete', [ActivationController::class, 'complete']);
                return;
            }

            $routes = [
                'set_service_counter' => [CallController::class, 'setServiceAndCounter'],
                'get_token_for_call' => [CallController::class, 'getTokensForCall'],
                'call_next' => [CallController::class, 'callNext'],
                'serve_token' => [CallController::class, 'serveToken'],
                'no_show' => [CallController::class, 'noShowToken'],
                'recall_token' => [CallController::class, 'recallToken'],
                'queue' => [KioskController::class, 'createToken'],
                'create_token' => [KioskController::class, 'createToken'],
            ];

            foreach ($routes as $key => $route) {
                add_action('wp_ajax_jltoken_' . $key, $route);
            }

            add_action('wp_ajax_nopriv_jltoken_create_token', [KioskController::class, 'createToken']);
        }
    }

    public static function footerText()
    {
        return '<span id="footer-thankyou">' . esc_html__('Powered by', 'jltoken') . ' <a href="https://www.justlabtech.com" target="_blank" rel="noopener noreferrer">Justlab Technologies</a>. ' . esc_html__('All rights reserved', 'jltoken') . '.</span>';
    }

    public static function footerVerText()
    {
        return '<p id="footer-upgrade" class="alignright"> JL Token ' . esc_html__('Version', 'jltoken') . ' ' . JLTOKEN_VERSION . ' </p>';
    }
}
