<?php

namespace Justlab\JLToken\Controllers;

use Justlab\JLToken\Models\CallStatus;
use Justlab\JLToken\Models\Counter;
use Justlab\JLToken\Models\Service;
use Justlab\JLToken\Repositories\ReportRepository;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class ReportController extends Controller
{
    const VIEW_DIR = JLTOKEN__PLUGIN_DIR . 'views/admin/reports/';

    private static $initiated = false;

    public static function init()
    {
        if (!self::$initiated) {
            self::initHooks();
        }
    }

    public static function initHooks()
    {
        self::$initiated = true;

        add_submenu_page('jltoken', esc_html__('Queue List', 'jltoken') . ' | JL Token', esc_html__('Queue List', 'jltoken'), 'manage_options', 'jltoken-queue-list', [self::class, 'queueList'], 4);
        add_submenu_page('jltoken', esc_html__('User Report', 'jltoken') . ' | JL Token', esc_html__('User Report', 'jltoken'), 'manage_options', 'jltoken-user-report', [self::class, 'userReport'], 5);
        add_submenu_page('jltoken', esc_html__('Monthly Report', 'jltoken') . ' | JL Token', esc_html__('Monthly Report', 'jltoken'), 'manage_options', 'jltoken-monthly-report', [self::class, 'monthlyReport'], 6);

        if (isset($_GET['page']) && (($_GET['page'] == 'jltoken-queue-list') || ($_GET['page'] == 'jltoken-user-report') || ($_GET['page'] == 'jltoken-monthly-report'))) {
            self::enqueueAssets();
        }
    }

    public static function queueList()
    {
        self::report();

        $starting_date = isset($_POST['starting_date']) ? trim($_POST['starting_date']) : '';
        $ending_date = isset($_POST['ending_date']) ? trim($_POST['ending_date']) : '';

        if ($starting_date && $ending_date) {
            $reports = ReportRepository::getQueueListReport($starting_date, $ending_date);
        }

        ob_start();
        include_once(self::VIEW_DIR . 'queue-list.php');
        $view = ob_get_contents();
        ob_end_clean();

        echo $view;
    }

    public static function userReport()
    {
        self::report();

        $user_id = isset($_POST['user_id']) ? trim($_POST['user_id']) : '';
        $date = isset($_POST['date']) ? trim($_POST['date']) : '';

        if ($date) {
            $reports = ReportRepository::getUserReport($user_id, $date);
        }

        ob_start();
        include_once(self::VIEW_DIR . 'user-report.php');
        $view = ob_get_contents();
        ob_end_clean();

        echo $view;
    }

    public static function monthlyReport()
    {
        self::report();

        $service_id = isset($_POST['service_id']) ? trim($_POST['service_id']) : '';
        $counter_id = isset($_POST['counter_id']) ? trim($_POST['counter_id']) : '';
        $user_id = isset($_POST['user_id']) ? trim($_POST['user_id']) : '';
        $call_status_id = isset($_POST['call_status_id']) ? trim($_POST['call_status_id']) : '';
        $starting_date = isset($_POST['starting_date']) ? trim($_POST['starting_date']) : '';
        $ending_date = isset($_POST['ending_date']) ? trim($_POST['ending_date']) : '';

        if ($starting_date && $ending_date) {
            $reports = ReportRepository::getMonthlyReport($service_id, $counter_id, $user_id, $call_status_id, $starting_date, $ending_date);
            $token_count = ReportRepository::getTokenCounts($starting_date, $ending_date);
        }

        $services = Service::all();
        $counters = Counter::all();
        $call_statuses = CallStatus::all();

        ob_start();
        include_once(self::VIEW_DIR . 'monthly-report.php');
        $view = ob_get_contents();
        ob_end_clean();

        echo $view;
    }

    public static function enqueueAssets()
    {
        wp_enqueue_style('jltoken-materialize');
        wp_enqueue_style('jltoken-app');
        wp_enqueue_style('jltoken-style');
        wp_enqueue_style('jltoken-main');
        wp_enqueue_style('jltoken-normalize');
        wp_enqueue_style('jltoken-datatable');

        wp_enqueue_script('jltoken-vendor');
        wp_enqueue_script('jltoken-datatable');
        wp_enqueue_script('jltoken-validate');
        wp_enqueue_script('jltoken-reports');
    }
}
