<?php

namespace Justlab\JLToken\Controllers;

use IgniteKit\Validation\ErrorBag;
use Justlab\JLToken\DB;
use Justlab\JLToken\Models\Service;
use Justlab\JLToken\Repositories\ServiceRepository;
use Justlab\JLToken\Validator\Validator;
use Throwable;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class ServiceController extends Controller
{
    const VIEW_DIR = JLTOKEN__PLUGIN_DIR . 'views/admin/services/';

    private static $initiated = false;

    public static function init()
    {
        if (!self::$initiated) {
            self::initHooks();
        }
    }

    public static function initHooks()
    {
        self::$initiated = true;

        add_submenu_page('jltoken', esc_html__('Services', 'jltoken') . ' | JL Token', esc_html__('Services', 'jltoken'), 'manage_options', 'jltoken-services', [self::class, 'findPage'], 2);
    }

    public static function findPage()
    {
        self::service();

        $view = isset($_GET['view']) ? trim($_GET['view']) : '';

        switch ($view) {
            case '':
            case 'list':
                self::listView();
                break;
            case 'create':
                if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                    $result = self::store();
                }
                self::create($result);
                break;
            case 'edit':
                if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                    $result = self::update();
                }
                self::edit($result);
                break;
            default:
                self::listView();
        }
    }

    public static function listView()
    {
        self::service();

        ob_start();
        include_once(self::VIEW_DIR . 'list.php');
        $view = ob_get_contents();
        ob_end_clean();

        echo $view;
    }

    public static function create($result)
    {
        self::service();

        if ($result instanceof ErrorBag) {
            $errors = $result;
            unset($result);
        }

        ob_start();
        include_once(self::VIEW_DIR . 'form.php');
        $view = ob_get_contents();
        ob_end_clean();

        echo $view;
    }

    public static function store()
    {
        self::service();

        check_admin_referer('jltoken-services-create');

        $data = [];

        $data['name'] = isset($_POST['name']) ? trim($_POST['name']) : '';
        $data['letter'] = isset($_POST['letter']) ? trim($_POST['letter']) : '';
        $data['start_number'] = isset($_POST['start_number']) ? trim($_POST['start_number']) : '';
        $data['ask_name'] = isset($_POST['ask_name']) ? trim($_POST['ask_name']) : '';
        $data['ask_email'] = isset($_POST['ask_email']) ? trim($_POST['ask_email']) : '';
        $data['ask_phone'] = isset($_POST['ask_phone']) ? trim($_POST['ask_phone']) : '';
        $data['name_required'] = isset($_POST['name_required']) ? trim($_POST['name_required']) : '';
        $data['email_required'] = isset($_POST['email_required']) ? trim($_POST['email_required']) : '';
        $data['phone_required'] = isset($_POST['phone_required']) ? trim($_POST['phone_required']) : '';
        $data['status'] = isset($_POST['status']) ? trim($_POST['status']) : '';

        $validator = new Validator;

        $validation = $validator->validate($data, [
            'name' => 'required|max:60|unique:services,name',
            'letter' => 'required|max:2|unique:services,letter',
            'start_number' => 'required|integer|min:1',
            'ask_name' => 'required|in:1,0',
            'ask_email' => 'required|in:1,0',
            'ask_phone' => 'required|in:1,0',
            'status' => 'required|in:1,0',
        ]);

        if ($validation->fails()) {
            return $validation->errors();
        }

        DB::beginTransaction();
        try {
            $service = ServiceRepository::create($data);
        } catch (Throwable $th) {
            DB::rollback();

            return 0;
        }
        DB::commit();

        return $service;
    }

    public static function edit($result)
    {
        self::service();

        $service_id = isset($_GET['id']) ? trim($_GET['id']) : '';
        $service = Service::find($service_id);

        if ($result instanceof ErrorBag) {
            $errors = $result;
            unset($result);
        }

        ob_start();
        include_once(self::VIEW_DIR . 'form.php');
        $view = ob_get_contents();
        ob_end_clean();

        echo $view;
    }

    public static function update()
    {
        self::service();

        check_admin_referer('jltoken-services-edit');

        $data = [];

        $data['id'] = isset($_POST['id']) ? trim($_POST['id']) : '';
        $data['name'] = isset($_POST['name']) ? trim($_POST['name']) : '';
        $data['letter'] = isset($_POST['letter']) ? trim($_POST['letter']) : '';
        $data['start_number'] = isset($_POST['start_number']) ? trim($_POST['start_number']) : '';
        $data['ask_name'] = isset($_POST['ask_name']) ? trim($_POST['ask_name']) : '';
        $data['ask_email'] = isset($_POST['ask_email']) ? trim($_POST['ask_email']) : '';
        $data['ask_phone'] = isset($_POST['ask_phone']) ? trim($_POST['ask_phone']) : '';
        $data['name_required'] = isset($_POST['name_required']) ? trim($_POST['name_required']) : '';
        $data['email_required'] = isset($_POST['email_required']) ? trim($_POST['email_required']) : '';
        $data['phone_required'] = isset($_POST['phone_required']) ? trim($_POST['phone_required']) : '';
        $data['status'] = isset($_POST['status']) ? trim($_POST['status']) : '';

        $validator = new Validator;
        $validation = $validator->validate($data, [
            'id' => 'required|integer|exists:services,id',
            'name' => 'required|max:60|unique:services,name,' . $data['id'],
            'letter' => 'required|max:2|unique:services,letter,' . $data['id'],
            'start_number' => 'required|integer|min:1',
            'ask_name' => 'required|in:1,0',
            'ask_email' => 'required|in:1,0',
            'ask_phone' => 'required|in:1,0',
            'name_required' => 'nullable|in:1,0',
            'email_required' => 'nullable|in:1,0',
            'phone_required' => 'nullable|in:1,0',
            'status' => 'required|in:1,0',
        ]);

        if ($validation->fails()) {
            return $validation->errors();
        }

        DB::beginTransaction();
        try {
            $service = Service::find($data['id']);
            $service = ServiceRepository::update($service, $data);
        } catch (Throwable $th) {
            DB::rollback();

            return 0;
        }
        DB::commit();

        return $service;
    }
}
