<?php

namespace Justlab\JLToken\Controllers;

use IgniteKit\Validation\ErrorBag;
use Justlab\JLToken\DB;
use Justlab\JLToken\Models\Setting;
use Justlab\JLToken\Models\Voice;
use Justlab\JLToken\Validator\Validator;
use Throwable;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class SettingController extends Controller
{
    const VIEW_DIR = JLTOKEN__PLUGIN_DIR . 'views/admin/settings/';

    private static $initiated = false;

    public static function init()
    {
        if (!self::$initiated) {
            self::initHooks();
        }
    }

    public static function initHooks()
    {
        self::$initiated = true;

        add_submenu_page('jltoken', esc_html__('Settings', 'jltoken') . ' | JL Token', esc_html__('Settings', 'jltoken'), 'manage_options', 'jltoken-settings', [self::class, 'view'], 7);
    }

    public static function view()
    {
        self::settings();

        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $result = self::update();
        }

        if (isset($result) && ($result instanceof ErrorBag)) {
            $errors = $result;
        }

        $settings = Setting::find(1);
        $voices = Voice::all();

        ob_start();
        include_once(self::VIEW_DIR . 'settings.php');
        $view = ob_get_contents();
        ob_end_clean();

        echo $view;
    }

    public static function update()
    {
        self::settings();

        check_admin_referer('jltoken-settings');

        $data = [];
        $data['voice_id'] = isset($_POST['voice_id']) ? trim($_POST['voice_id']) : '';
        $data['notification'] = isset($_POST['notification']) ? trim($_POST['notification']) : '';
        $data['font_size'] = isset($_POST['font_size']) ? trim($_POST['font_size']) : '';
        $data['font_color'] = isset($_POST['font_color']) ? trim($_POST['font_color']) : '';
        $data['show_on_display'] = isset($_POST['show_on_display']) ? trim($_POST['show_on_display']) : '';

        $validator = new Validator;
        $validation = $validator->validate($data, [
            'voice_id' => 'required|exists:voices,id',
            'font_size' => 'integer',
            'font_color' => 'max:60',
            'show_on_display' => 'nullable|in:name,email,phone',
        ]);

        if ($validation->fails()) {
            return $validation->errors();
        }

        DB::beginTransaction();
        try {
            $settings = Setting::find(1);
            $settings->voice_id = $data['voice_id'];
            $settings->notification = $data['notification'];
            $settings->font_size = $data['font_size'];
            $settings->font_color = $data['font_color'];
            $settings->show_on_display = $data['show_on_display'] ? $data['show_on_display'] : null;
            $settings->save();
        } catch (Throwable $th) {
            DB::rollback();

            return 0;
        }
        DB::commit();

        return $settings;
    }
}
