<?php

namespace Justlab\JLToken\Repositories;

use Justlab\JLToken\Constant;
use Justlab\JLToken\Models\Call;
use Justlab\JLToken\Models\Counter;
use Justlab\JLToken\Models\Queue;
use Justlab\JLToken\Utility;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class CallRepository
{
    public static function callNext($service_id, $counter_id)
    {
        $already_called = Call::builder()
            ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
            ->where(['service_id' => $service_id])
            ->where(['counter_id' => $counter_id])
            ->where(['call_status_id' =>  NULL])
            ->first(ARRAY_A);
        $already_called = $already_called ? new Call($already_called) : $already_called;

        if ($already_called) {
            return $already_called;
        }

        $queue = Queue::builder()
            ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
            ->where(['called' => 0])
            ->where(['service_id' => $service_id])
            ->first(ARRAY_A);
        $queue = $queue ? new Queue($queue) : $queue;

        if (!$queue) {
            return null;
        }

        $called_position = $queue->position;

        $call = Call::insert([
            'queue_id' => $queue->id,
            'service_id' => $queue->service_id,
            'counter_id' => $_SESSION['jltoken_counter']->id,
            'user_id' => wp_get_current_user()->ID,
            'letter' => $queue->letter,
            'number' => $queue->number,
            'called_date' => Utility::now()->toDateString(),
            'started_at' => Utility::now()->format('Y-m-d H:i:s'),
            'waiting_time' => Utility::parse($queue->created_at)->diff(Utility::now())->format('%H:%I:%S'),
            'created_at' => Utility::now()->format('Y-m-d H:i:s'),
            'updated_at' => Utility::now()->format('Y-m-d H:i:s')
        ]);

        $queue->position = 0;
        $queue->called = 1;
        $queue->updated_at = Utility::now()->format('Y-m-d H:i:s');
        $queue->save();

        self::decrementPostion($queue->service_id, $called_position);

        return $call;
    }

    public static function callnextTokenById($queue_id, $service_id)
    {
        $queue = Queue::builder()
            ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
            ->where(['called' => 0])
            ->where(['id' => $queue_id])
            ->where(['service_id' => $service_id])
            ->first(ARRAY_A);
        $queue = $queue ? new Queue($queue) : $queue;

        if (!$queue) {
            return null;
        }

        $called_position = $queue->position;

        $call = Call::insert([
            'queue_id' => $queue->id,
            'service_id' => $queue->service_id,
            'counter_id' => $_SESSION['jltoken_counter']->id,
            'user_id' => wp_get_current_user()->ID,
            'letter' => $queue->letter,
            'number' => $queue->number,
            'called_date' => Utility::now()->toDateString(),
            'started_at' => Utility::now()->format('Y-m-d H:i:s'),
            'waiting_time' => Utility::parse($queue->created_at)->diff(Utility::now())->format('%H:%I:%S'),
            'created_at' => Utility::now()->format('Y-m-d H:i:s'),
            'updated_at' => Utility::now()->format('Y-m-d H:i:s')
        ]);

        $queue->called = 1;
        $queue->position = 0;
        $queue->updated_at = Utility::now()->format('Y-m-d H:i:s');
        $queue->save();

        self::decrementPostion($queue->service_id, $called_position);

        return $call;
    }

    public static function serveToken(Call $call)
    {
        $call->ended_at = Utility::now()->format("Y-m-d H:i:s");
        $call->served_time = Utility::parse($call->started_at)->diff(Utility::now())->format('%H:%I:%S');
        $call->turn_around_time = Utility::parse($call->waiting_time)->add(Utility::parse($call->started_at)->diff(Utility::now()))->toTimeString();
        $call->call_status_id = Constant::CALL_STATUS_SERVED;
        $call->updated_at = Utility::now()->format('Y-m-d H:i:s');
        $call->save();

        return $call;
    }

    public static function noShowToken(Call $call)
    {
        $call->ended_at = Utility::now()->format('Y-m-d H:i:s');
        $call->call_status_id = Constant::CALL_STATUS_NO_SHOW;
        $call->updated_at = Utility::now()->format('Y-m-d H:i:s');
        $call->save();

        return $call;
    }

    public static function recallToken(Call $call)
    {
        $new_call = Call::insert([
            'queue_id' => $call->queue_id,
            'service_id' => $call->service_id,
            'counter_id' => $call->counter_id,
            'user_id' => $call->user_id,
            'letter' => $call->letter,
            'number' => $call->number,
            'called_date' => $call->called_date,
            'started_at' => $call->started_at,
            'waiting_time' => $call->waiting_time,
            'created_at' => Utility::now()->format('Y-m-d H:i:s'),
            'updated_at' => Utility::now()->format('Y-m-d H:i:s')
        ]);

        $call->delete();

        return $new_call;
    }

    public static function setCallsForDisplay($service_id)
    {
        $calls = Call::builder()
            ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
            ->order_by('id', 'desc')
            ->limit(5)
            ->get(ARRAY_A, function ($row) {
                return new Call($row);
            });

        foreach ($calls as $key => $call) {
            $calls[$key]->queue = Queue::find($call->queue_id);
            $calls[$key]->counter = Counter::find($call->counter_id);
        }

        file_put_contents(JLTOKEN__PLUGIN_DIR . 'assets/files/tokens_for_display.json', json_encode($calls));


        $calls_service = Call::builder()
            ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
            ->where(['service_id' => $service_id])
            ->order_by('id', 'desc')
            ->limit(5)
            ->get(ARRAY_A, function ($row) {
                return new Call($row);
            });

        foreach ($calls_service as $key => $call_service) {
            $calls_service[$key]->queue = Queue::find($call->queue_id);
            $calls_service[$key]->counter = Counter::find($call_service->counter_id);
        }

        file_put_contents(JLTOKEN__PLUGIN_DIR . 'assets/files/service_' . $service_id . '_display.json', json_encode($calls_service));
    }

    public static function decrementPostion($service_id, $called_position)
    {
        $queues = Queue::builder()
            ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
            ->where(['position' => ['operator' => '>', 'value' => $called_position]])
            ->where(['service_id' => $service_id])
            ->get(ARRAY_A, function ($row) {
                return new Queue($row);
            });

        foreach ($queues as $queue) {
            $queue->position = $queue->position - 1;
            $queue->updated_at = Utility::now()->format('Y-m-d H:i:s');
            $queue->save();
        }
    }
}
