<?php

namespace Justlab\JLToken\Repositories;

use Justlab\JLToken\Models\Counter;
use Justlab\JLToken\Utility;
use TenQuality\WP\Database\QueryBuilder;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class CounterRepository
{
    public static function getTableData($order_by, $order, $search_term, $status, $page_number, $items_per_page)
    {
        $query = Counter::builder();

        if ($search_term) {
            $query->where(['name' => ['operator' => 'like', 'value' => "%$search_term%"]]);
        }

        if ($status) {
            $query->where(['status' => ($status == 'enabled' ? 1 : 0)]);
        }

        if ($order_by && $order) {
            $query->order_by($order_by, $order);
        }

        if ($page_number && $items_per_page) {
            $offset = ($page_number - 1) * $items_per_page;

            $query->limit($items_per_page)
                ->offset($offset);
        }

        return $query->get(ARRAY_A, function ($row) {
            return new Counter($row);
        });
    }

    public static function getCount($search_term, $status)
    {
        $query = Counter::builder();

        if ($status == 'enabled') {
            $query->where(['status' => 1]);
        } else if ($status == 'disabled') {
            $query->where(['status' => 0]);
        }

        if ($search_term) {
            $query->where(['name' => ['operator' => 'like', 'value' => "%$search_term%"]]);
        }

        return $query->count();
    }

    public static function getActiveCounters()
    {
        return Counter::where(['status' => 1]);
    }

    public static function create($data)
    {
        return Counter::insert([
            'name' => sanitize_text_field($data['name']),
            'status' => intval($data['status']),
            'created_at' => Utility::now()->format('Y-m-d H:i:s'),
            'updated_at' => Utility::now()->format('Y-m-d H:i:s')
        ]);
    }

    public static function changeStatus($ids, $status)
    {
        $ids = !is_array($ids) ? [$ids] : $ids;

        $status = (($status == 'enable') ? 1 : ($status == 'disable' ? 0 : null));

        if ($status === null) {
            return;
        }

        return Counter::builder()
            ->set(['status' => $status, 'updated_at' => Utility::now()->format('Y-m-d H:i:s')])
            ->where(['id' => ['operator' => 'in', 'value' =>  $ids]])
            ->update();
    }

    public static function delete($ids)
    {
        $ids = !is_array($ids) ? [$ids] : $ids;

        return QueryBuilder::create()
            ->from(Counter::TABLE)
            ->where(['id' => ['operator' => 'in', 'value' =>  $ids]])
            ->delete();
    }

    public static function update(Counter $counter, $data)
    {
        $counter->name = sanitize_text_field($data['name']);
        $counter->status = intval($data['status']);
        $counter->updated_at = Utility::now()->format('Y-m-d H:i:s');
        $counter->save();

        return $counter;
    }
}
