<?php

namespace Justlab\JLToken\Repositories;

use Justlab\JLToken\Constant;
use Justlab\JLToken\Models\Call;
use Justlab\JLToken\Models\Queue;
use Justlab\JLToken\Utility;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class DashboardRepository
{
    public static function getTodayData()
    {
        return [
            'today_queue' => Queue::builder()
                ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
                ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
                ->where(['called' => false])
                ->count(),

            'today_served' => Call::builder()
                ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
                ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
                ->where(['call_status_id' => Constant::CALL_STATUS_SERVED])
                ->count(),

            'today_noshow' => Call::builder()
                ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
                ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
                ->where(['call_status_id' => Constant::CALL_STATUS_NO_SHOW])
                ->count(),

            'today_serving' => Call::builder()
                ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
                ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
                ->where(['call_status_id' => NULL])
                ->count(),
        ];
    }

    public static function getTodayYesterdayData()
    {
        $t_6 = Queue::builder()->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->startOfDay()->addHours(6)->format('Y-m-d H:i:s')]])->count();
        $t_12 = Queue::builder()->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->startOfDay()->addHours(12)->format('Y-m-d H:i:s')]])->count();
        $t_18 = Queue::builder()->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->startOfDay()->addHours(18)->format('Y-m-d H:i:s')]])->count();
        $t_24 = Queue::builder()->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->startOfDay()->addHours(23)->addMinutes(59)->addSeconds(59)->format('Y-m-d H:i:s')]])->count();

        $today_data = array(0, $t_6, $t_12, $t_18, $t_24);

        $y_6 = Queue::builder()->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->yesterday()->startOfDay()->format('Y-m-d H:i:s')]])->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->yesterday()->startOfDay()->addHours(6)->format('Y-m-d H:i:s')]])->count();
        $y_12 = Queue::builder()->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->yesterday()->startOfDay()->format('Y-m-d H:i:s')]])->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->yesterday()->startOfDay()->addHours(12)->format('Y-m-d H:i:s')]])->count();
        $y_18 = Queue::builder()->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->yesterday()->startOfDay()->format('Y-m-d H:i:s')]])->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->yesterday()->startOfDay()->addHours(18)->format('Y-m-d H:i:s')]])->count();
        $y_24 = Queue::builder()->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->yesterday()->startOfDay()->format('Y-m-d H:i:s')]])->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->yesterday()->startOfDay()->addHours(23)->addMinutes(59)->addSeconds(59)->format('Y-m-d H:i:s')]])->count();

        $yesterday_data = array(0, $y_6, $y_12, $y_18, $y_24);

        return ['today' => $today_data, 'yesterday' => $yesterday_data];
    }
}
