<?php

namespace Justlab\JLToken\Repositories;

use Justlab\JLToken\Constant;
use Justlab\JLToken\Models\Call;
use Justlab\JLToken\Models\Queue;
use Justlab\JLToken\Utility;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class ReportRepository
{
    public static function getQueueListReport($starting_date, $ending_date)
    {
        return Queue::builder()
            ->select('jltoken_services.name as service_name, jltoken_queues.created_at as date, jltoken_queues.number as number, jltoken_queues.letter as letter, jltoken_queues.called as called, jltoken_queues.name as name, jltoken_queues.email as email, jltoken_queues.phone as phone, users.user_nicename as user_name, jltoken_counters.name as counter_name')
            ->join('jltoken_calls as `jltoken_calls`', [['raw' => 'jltoken_queues.id = jltoken_calls.queue_id']], true)
            ->join('jltoken_services as `jltoken_services`', [['raw' => 'jltoken_queues.service_id = jltoken_services.id']], true)
            ->join('jltoken_counters as `jltoken_counters`', [['raw' => 'jltoken_calls.counter_id = jltoken_counters.id']], true)
            ->join('users as `users`', [['raw' => 'jltoken_calls.user_id = users.ID']], true)
            ->where(['jltoken_queues.created_at' => ['operator' => '>=', 'value' => Utility::parse($starting_date)->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['jltoken_queues.created_at' => ['operator' => '<=', 'value' => Utility::parse($ending_date)->endOfDay()->format('Y-m-d H:i:s')]])
            ->get();
    }

    public static function getUserReport($user_id, $date)
    {
        $query = Call::builder()
            ->select('jltoken_calls.id, jltoken_calls.number, jltoken_calls.letter, jltoken_counters.name as counter_name, jltoken_services.name as service_name, jltoken_queues.name as name, jltoken_queues.email as email, jltoken_queues.phone as phone')
            ->join('jltoken_queues as `jltoken_queues`', [['raw' => 'jltoken_calls.queue_id = jltoken_queues.id']], true)
            ->join('jltoken_services as `jltoken_services`', [['raw' => 'jltoken_calls.service_id = jltoken_services.id']], true)
            ->join('jltoken_counters as `jltoken_counters`', [['raw' => 'jltoken_calls.counter_id = jltoken_counters.id']], true)
            ->where(['jltoken_calls.called_date' => $date]);

        if ($user_id) {
            $query->where(['jltoken_calls.user_id' => $user_id]);
        }

        return $query->get();
    }

    public static function getMonthlyReport($service_id, $counter_id, $user_id, $call_status_id, $starting_date, $ending_date)
    {
        $query = Call::builder()
            ->select('users.user_nicename as user_name, jltoken_queues.letter as letter, jltoken_queues.number as number, jltoken_services.name as service_name, jltoken_counters.name as counter_name, jltoken_queues.created_at as date, jltoken_queues.name as name, jltoken_queues.email as email, jltoken_queues.phone as phone, jltoken_calls.started_at as called_at, jltoken_calls.ended_at as served_at, jltoken_calls.waiting_time as waiting_time, jltoken_calls.served_time as served_time, jltoken_calls.turn_around_time as total_time, jltoken_call_statuses.name as status')
            ->join('jltoken_services as `jltoken_services`', [['raw' => 'jltoken_calls.service_id = jltoken_services.id']], true)
            ->join('jltoken_counters as `jltoken_counters`', [['raw' => 'jltoken_calls.counter_id = jltoken_counters.id']], true)
            ->join('users as `users`', [['raw' => 'jltoken_calls.user_id = users.ID']], true)
            ->join('jltoken_call_statuses as `jltoken_call_statuses`', [['raw' => 'jltoken_calls.call_status_id = jltoken_call_statuses.id']], true)
            ->join('jltoken_queues as `jltoken_queues`', [['raw' => 'jltoken_calls.queue_id = jltoken_queues.id']], 'RIGHT')
            ->where(['jltoken_queues.created_at' => ['operator' => '>=', 'value' => Utility::parse($starting_date)->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['jltoken_queues.created_at' => ['operator' => '<=', 'value' => Utility::parse($ending_date)->endOfDay()->format('Y-m-d H:i:s')]]);

        if ($service_id) $query->where(['jltoken_queues.service_id' => $service_id]);
        if ($counter_id) $query->where(['jltoken_calls.counter_id' => $counter_id]);
        if ($user_id) $query->where(['jltoken_calls.user_id' => $user_id]);
        if ($call_status_id) $query->where(['jltoken_calls.call_status_id' => $call_status_id]);

        return $query->order_by('jltoken_queues.created_at', 'asc')
            ->get();
    }

    public static function getTokenCounts($starting_date, $ending_date)
    {
        return [
            'queue' => Queue::builder()
                ->where(['created_at' => ['operator' => '>=', 'value' => Utility::parse($starting_date)->startOfDay()->format('Y-m-d H:i:s')]])
                ->where(['created_at' => ['operator' => '<=', 'value' => Utility::parse($ending_date)->endOfDay()->format('Y-m-d H:i:s')]])
                ->where(['called' => 0])
                ->count(),

            'served' => Call::builder()
                ->where(['created_at' => ['operator' => '>=', 'value' => Utility::parse($starting_date)->startOfDay()->format('Y-m-d H:i:s')]])
                ->where(['created_at' => ['operator' => '<=', 'value' => Utility::parse($ending_date)->endOfDay()->format('Y-m-d H:i:s')]])
                ->where(['call_status_id' => Constant::CALL_STATUS_SERVED])
                ->count(),

            'noshow' => Call::builder()
                ->where(['created_at' => ['operator' => '>=', 'value' => Utility::parse($starting_date)->startOfDay()->format('Y-m-d H:i:s')]])
                ->where(['created_at' => ['operator' => '<=', 'value' => Utility::parse($ending_date)->endOfDay()->format('Y-m-d H:i:s')]])
                ->where(['call_status_id' => Constant::CALL_STATUS_NO_SHOW])
                ->count(),

            'serving' => Call::builder()
                ->where(['created_at' => ['operator' => '>=', 'value' => Utility::parse($starting_date)->startOfDay()->format('Y-m-d H:i:s')]])
                ->where(['created_at' => ['operator' => '<=', 'value' => Utility::parse($ending_date)->endOfDay()->format('Y-m-d H:i:s')]])
                ->where(['call_status_id' => NULL])
                ->count(),
        ];
    }
}
