<?php

namespace Justlab\JLToken\Repositories;

use Justlab\JLToken\Models\Service;
use Justlab\JLToken\Utility;
use TenQuality\WP\Database\QueryBuilder;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class ServiceRepository
{
    public static function getTableData($order_by, $order, $search_term, $status, $page_number, $items_per_page)
    {
        $query = Service::builder();

        if ($search_term) {
            $query->where(['name' => ['operator' => 'like', 'value' => "%$search_term%"]]);
        }

        if ($status) {
            $query->where(['status' => ($status == 'enabled' ? 1 : 0)]);
        }

        if ($order_by && $order) {
            $query->order_by($order_by, $order);
        }

        if ($page_number && $items_per_page) {
            $offset = ($page_number - 1) * $items_per_page;

            $query->limit($items_per_page)
                ->offset($offset);
        }

        return $query->get(ARRAY_A, function ($row) {
            return new Service($row);
        });
    }

    public static function getCount($search_term, $status)
    {
        $query = Service::builder();

        if ($status == 'enabled') {
            $query->where(['status' => 1]);
        } else if ($status == 'disabled') {
            $query->where(['status' => 0]);
        }

        if ($search_term) {
            $query->where(['name' => ['operator' => 'like', 'value' => "%$search_term%"]]);
        }

        return $query->count();
    }

    public static function getActiveServices()
    {
        return Service::where(['status' => 1]);
    }

    public static function create($data)
    {
        return Service::insert([
            'name' => sanitize_text_field($data['name']),
            'letter' => sanitize_text_field($data['letter']),
            'start_number' => intval($data['start_number']),
            'ask_name' => intval($data['ask_name']),
            'ask_email' => intval($data['ask_email']),
            'ask_phone' => intval($data['ask_phone']),
            'name_required' => intval($data['ask_name']) ? intval($data['name_required']) : 0,
            'email_required' => intval($data['ask_email']) ? intval($data['email_required']) : 0,
            'phone_required' => intval($data['ask_phone']) ? intval($data['phone_required']) : 0,
            'status' => intval($data['status']),
            'created_at' => Utility::now()->format('Y-m-d H:i:s'),
            'updated_at' => Utility::now()->format('Y-m-d H:i:s')
        ]);
    }

    public static function changeStatus($ids, $status)
    {
        global $wpdb;

        $ids = !is_array($ids) ? [$ids] : $ids;

        $status = (($status == 'enable') ? 1 : ($status == 'disable' ? 0 : null));

        if ($status === null) {
            return;
        }

        return Service::builder()
            ->set(['status' => $status, 'updated_at' => Utility::now()->format('Y-m-d H:i:s')])
            ->where(['id' => ['operator' => 'in', 'value' =>  $ids]])
            ->update();
    }

    public static function delete($ids)
    {
        $ids = !is_array($ids) ? [$ids] : $ids;

        return QueryBuilder::create()
            ->from(Service::TABLE)
            ->where(['id' => ['operator' => 'in', 'value' =>  $ids]])
            ->delete();
    }

    public static function update(Service $service, $data)
    {
        $service->name = sanitize_text_field($data['name']);
        $service->letter = sanitize_text_field($data['letter']);
        $service->start_number = intval($data['start_number']);
        $service->ask_name = intval($data['ask_name']);
        $service->ask_email = intval($data['ask_email']);
        $service->ask_phone = intval($data['ask_phone']);
        $service->name_required = intval($data['ask_name']) ? intval($data['name_required']) : 0;
        $service->email_required = intval($data['ask_email']) ? intval($data['email_required']) : 0;
        $service->phone_required = intval($data['ask_phone']) ? intval($data['phone_required']) : 0;
        $service->status = intval($data['status']);
        $service->updated_at = Utility::now()->format('Y-m-d H:i:s');
        $service->save();

        return $service;
    }
}
