<?php

namespace Justlab\JLToken\Repositories;

use Justlab\JLToken\Models\Call;
use Justlab\JLToken\Models\Queue;
use Justlab\JLToken\Models\Service;
use Justlab\JLToken\Utility;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class TokenRepository
{
    public static function createToken(Service $service, $data)
    {
        $last_token = self::getLatestToken($service);

        $token_number = $last_token ? ($last_token->number + 1) : $service->start_number;

        return Queue::insert([
            'service_id' => $service->id,
            'reference_no' => wp_rand(1000000000, 9999999999),
            'letter' => $service->letter,
            'number' => $token_number,
            'called' => 0,
            'position' => (self::customerWaiting($service) + 1),
            'name' => $data['name'] ?? null,
            'email' => $data['email'] ?? null,
            'phone' => $data['phone'] ?? null,
            'created_at' => Utility::now()->format('Y-m-d H:i:s'),
            'updated_at' => Utility::now()->format('Y-m-d H:i:s')
        ]);
    }

    public static function getLatestToken(Service $service)
    {
        $queue = Queue::builder()
            ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->endOfDay()->format('Y-m-d H:i:s')]])
            ->where(['service_id' => $service->id])
            ->order_by('created_at', 'desc')
            ->first(ARRAY_A);

        return $queue ? new Queue($queue) : $queue;
    }

    public static function customerWaiting(Service $service)
    {
        return Queue::builder()
            ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
            ->where(['called' => 0])
            ->where(['service_id' => $service->id])
            ->count();
    }

    public static function getTokensForCall(Service $service)
    {
        return Queue::builder()
            ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
            ->where(['called' => 0])
            ->where(['service_id' => $service->id])
            ->get(ARRAY_A, function ($row) {
                return new Queue($row);
            });
    }

    public static function getCalledTokens($service, $counter)
    {
        return Call::builder()
            ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
            ->where(['service_id' => $service->id])
            ->where(['counter_id' => $counter->id])
            ->order_by('created_at', 'desc')
            ->get(ARRAY_A, function ($row) {
                return new Call($row);
            });
    }

    public static function setTokensOnFile()
    {
        $tokens_for_call = Queue::builder()
            ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
            ->where(['called' => 0])
            ->get(ARRAY_A, function ($row) {
                return new Queue($row);
            });

        $called_tokens = Call::builder()
            ->where(['created_at' => ['operator' => '>=', 'value' => Utility::now()->startOfDay()->format('Y-m-d H:i:s')]])
            ->where(['created_at' => ['operator' => '<=', 'value' => Utility::now()->format('Y-m-d H:i:s')]])
            ->order_by('created_at', 'desc')
            ->get(ARRAY_A, function ($row) {
                return new Call($row);
            });

        $data = [];
        $data['tokens_for_call'] = $tokens_for_call;
        $data['called_tokens'] = $called_tokens;

        file_put_contents(JLTOKEN__PLUGIN_DIR . 'assets/files/tokens_for_callpage.json', json_encode($data));
    }
}
