<?php

namespace Justlab\JLToken\Tables;

use Justlab\JLToken\Repositories\CounterRepository;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class CounterListTable extends ListTable
{
    public $order_by;
    public $order;
    public $page_number;
    public $search_term;
    public $status;

    public $all_count = 0;
    public $enabled_count = 0;
    public $disabled_count = 0;

    public $is_bulk_action_success = 0;
    public $is_delete_success = 0;

    protected $items_per_page = 10;

    public function prepare_items()
    {
        if ($_SERVER['REQUEST_METHOD'] === 'POST' && !check_admin_referer('bulk-counters')) {
            esc_html_e("Invalid Request", 'jltoken');
            exit;
        }

        $this->is_delete_success = $this->do_delete();

        $this->is_bulk_action_success = $this->do_bulk_actions();

        $this->order_by = isset($_GET['orderby']) ? trim($_GET['orderby']) : "";
        $this->order = isset($_GET['order']) ? trim($_GET['order']) : "";
        $this->page_number = isset($_GET['paged']) ? trim($_GET['paged']) : 1;
        $this->search_term = isset($_POST['s']) ? trim($_POST['s']) : "";
        $this->status = isset($_GET['status']) ? trim($_GET['status']) : '';

        $this->set_counts();

        $this->set_pagination_args([
            'total_items' => CounterRepository::getCount($this->search_term, $this->status),
            'per_page' => $this->items_per_page,
        ]);

        $this->items = CounterRepository::getTableData($this->order_by, $this->order, $this->search_term, $this->status, $this->page_number, $this->items_per_page);

        $columns = $this->get_columns();
        $hidden = $this->get_hidden_columns();
        $sortable = $this->get_sortable_columns();

        $this->_column_headers = array($columns, $hidden, $sortable);
    }

    public function set_counts()
    {
        $this->all_count = CounterRepository::getCount(null, null);
        $this->enabled_count = CounterRepository::getCount(null, 'enabled');
        $this->disabled_count = CounterRepository::getCount(null, 'disabled');
    }

    public function get_hidden_columns()
    {
        return [];
    }

    public function get_sortable_columns()
    {
        return [
            "name" => ["name", false],
            "start_number" => ["start_number", false],
        ];
    }

    public function get_columns()
    {
        $columns = [
            "cb" => "<input type='checkbox'>",
            "name" => esc_html__("Name", 'jltoken'),
            "status" => esc_html__("Status", 'jltoken'),
            "actions" => esc_html__("Actions", 'jltoken'),
        ];

        return $columns;
    }

    public function column_default($item, $column_name)
    {
        switch ($column_name) {
            case 'name':
                return $item->$column_name;
                break;
            case 'status':
                return '<span class="badge ' . ($item->$column_name ? 'badge-success' : 'badge-warning') . '">' . ($item->$column_name ? esc_html__('Enabled', 'jltoken') : esc_html__('Disabled', 'jltoken')) . '</span>';
                break;
            case 'actions':
                return '<a href="' . admin_url('admin.php?page=jltoken-counters&view=edit&id=' . $item->id) . '" class="dashicons dashicons-edit" title="' . esc_html__('Edit', 'jltoken') . '"></a><button type="submit" class="delete" title="' . esc_html__('Delete', 'jltoken') . '" name="delete" value="' . $item->id . '"><span class="dashicons dashicons-trash"></span></button>';
                break;
            default:
                return "no value";
        }
    }

    public function column_cb($item)
    {
        return "<input type='checkbox' name='bulk_actions_ids[]' value='" . $item->id . "'>";
    }

    public function get_bulk_actions()
    {
        $actions = [
            'enable' => esc_html__('Enable', 'jltoken'),
            'disable' => esc_html__('Disable', 'jltoken'),
            'delete' => esc_html__('Delete', 'jltoken'),
        ];

        return $actions;
    }

    public function do_delete()
    {
        if ($this->can_do_delete()) {
            return CounterRepository::delete(trim($_POST['delete']));
        }

        return 0;
    }

    public function can_do_delete()
    {
        return isset($_POST['delete']) && trim($_POST['delete']);
    }

    public function available_bulk_actions()
    {
        return ['enable', 'disable', 'delete'];
    }

    public function do_bulk_actions()
    {
        if ($this->can_do_bulk_actions()) {
            switch ($this->get_bulk_action()) {
                case 'enable':
                    return CounterRepository::changeStatus($_POST['bulk_actions_ids'], 'enable');
                    break;
                case 'disable':
                    return CounterRepository::changeStatus($_POST['bulk_actions_ids'], 'disable');
                    break;
                case 'delete':
                    return CounterRepository::delete($_POST['bulk_actions_ids']);
                    break;
                default:
                    return 0;
                    break;
            }
        }

        return 0;
    }

    public function can_do_bulk_actions()
    {
        return isset($_POST['bulk_actions_ids']) && is_array($_POST['bulk_actions_ids']) && isset($_POST['action2']) && in_array($this->get_bulk_action(), $this->available_bulk_actions());
    }

    public function get_bulk_action()
    {
        return trim($_POST['action2']);
    }
}
