<?php

namespace Justlab\JLToken;

use Carbon\Carbon;
use DateTimeImmutable;
use DateTimeZone;
use RecursiveDirectoryIterator;
use RecursiveIteratorIterator;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}

class Utility
{
    static $notice_classes = [
        'i' => 'notice-info',
        's' => 'notice-success',
        'w' => 'notice-warning',
        'e' => 'notice-error',
    ];

    public static function notice($message, $type = 's')
    {
        printf('<div class="jltoken-notice %1$s"><p>%2$s</p></div>', 'notice notice-alt ' . esc_attr(self::$notice_classes[$type]), esc_html($message));
    }

    public static function issetValue($item)
    {
        return (isset($item) && $item);
    }

    public static function issetValueOld($item, $key)
    {
        if (self::issetValue($item)) {
            return isset($_POST[$key]) ? trim($_POST[$key]) : $item->$key;
        } else if (!self::issetValue($item) && isset($_POST[$key])) {
            return trim($_POST[$key]);
        }

        return '';
    }

    public static function createDir($dir)
    {
        if (!is_dir($dir)) {
            mkdir($dir);
        }
    }

    public static function deleteDir($dir)
    {
        $it = new RecursiveDirectoryIterator($dir, RecursiveDirectoryIterator::SKIP_DOTS);
        $files = new RecursiveIteratorIterator($it, RecursiveIteratorIterator::CHILD_FIRST);
        foreach ($files as $file) {
            if ($file->isDir()) {
                rmdir($file->getRealPath());
            } else {
                unlink($file->getRealPath());
            }
        }
        rmdir($dir);
    }

    public static function now(): Carbon
    {
        return Carbon::parse(new DateTimeImmutable('now', self::wpTimezone()));
    }

    public static function parse($date): Carbon
    {
        return Carbon::parse($date, self::wpTimezone());
    }

    public static function createFromFormat($format, $time): Carbon
    {
        return Carbon::createFromFormat($format, $time, self::wpTimezone());
    }

    // @param date 
    public static function dateToCarbon(string $date): Carbon
    {
        return Carbon::createFromFormat('Y-m-d H:i:s', $date);
    }

    public static function wpTimezone()
    {
        $timezone_string = get_option('timezone_string');

        if ($timezone_string) {
            return new DateTimeZone($timezone_string);
        }

        $offset  = (float) get_option('gmt_offset');
        $hours   = (int) $offset;
        $minutes = ($offset - $hours);

        $sign      = ($offset < 0) ? '-' : '+';
        $abs_hour  = abs($hours);
        $abs_mins  = abs($minutes * 60);
        $tz_offset = sprintf('%s%02d:%02d', $sign, $abs_hour, $abs_mins);

        return new DateTimeZone($tz_offset);
    }
}
