<?php

use Justlab\JLToken\Utility;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}
?>
<div class="wrap" id="services-form">
    <h1 id="wp-heading-inline">
        <a href="<?php echo admin_url('admin.php?page=jltoken-services') ?>">
            <span class="dashicons dashicons-arrow-left-alt" title="<?php esc_html_e('Back', 'jltoken') ?>"></span>
        </a>
        <?php Utility::issetValue($service) ? esc_html_e('Update Service', 'jltoken') : esc_html_e('Add New Service', 'jltoken') ?>
    </h1>
    <?php
    if (isset($result) && $result) {
        Utility::notice(Utility::issetValue($service) ? esc_html__('Service updated successfully!', 'jltoken') : esc_html__('Service created successfully!', 'jltoken'));
        if (!Utility::issetValue($service)) {
            $_POST = [];
        }
    } else if (isset($result) && !$result) {
        Utility::notice(esc_html__('Something went wrong. Please try again', 'jltoken'), 'e');
    }
    ?>
    <p><?php Utility::issetValue($service) ? esc_html_e('Update an existing Service', 'jltoken') : esc_html_e('Create a brand new Service.', 'jltoken') ?></p>
    <form method="post">
        <input name="action" type="hidden" value="<?php echo Utility::issetValue($service) ? 'edit' : 'create' ?>-service">
        <?php wp_nonce_field('jltoken-services-' . (Utility::issetValue($service) ? 'edit' : 'create')) ?>
        <?php echo Utility::issetValue($service) ? '<input type="hidden" name="id" value="' . $service->id . '">' : '' ?>
        <table class="form-table" role="presentation">
            <tbody>
                <tr class="form-field form-required <?php echo (isset($errors) && $errors->has('name')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="name">
                            <?php esc_html_e('Name', 'jltoken') ?>
                            <span class="description">(<?php esc_html_e('required', 'jltoken') ?>)</span>
                        </label>
                    </th>
                    <td>
                        <input name="name" type="text" id="name" value="<?php echo Utility::issetValueOld($service, 'name') ?>" aria-required="true" autocorrect="off" autocomplete="off" maxlength="60">
                        <?php if (isset($errors) && $errors->has('name')) { ?>
                            <p class="error"><?php echo $errors->first('name') ?></p>
                        <?php } ?>
                    </td>
                </tr>
                <tr class="form-field form-required <?php echo (isset($errors) && $errors->has('letter')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="letter">
                            <?php esc_html_e('Letter', 'jltoken') ?>
                            <span class="description">(<?php esc_html_e('required', 'jltoken') ?>)</span>
                        </label>
                    </th>
                    <td>
                        <input name="letter" type="text" id="letter" value="<?php echo Utility::issetValueOld($service, 'letter') ?>" aria-required="true" autocorrect="off" autocomplete="off" maxlength="2">
                        <?php if (isset($errors) && $errors->has('letter')) { ?>
                            <p class="error"><?php echo $errors->first('letter') ?></p>
                        <?php } ?>
                    </td>
                </tr>
                <tr class="form-field form-required <?php echo (isset($errors) && $errors->has('start_number')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="start_number">
                            <?php esc_html_e('Start Number', 'jltoken') ?>
                            <span class="description">(<?php esc_html_e('required', 'jltoken') ?>)</span>
                        </label>
                    </th>
                    <td>
                        <input name="start_number" type="number" id="start_number" value="<?php echo Utility::issetValueOld($service, 'start_number') ?>" aria-required="true" autocorrect="off" autocomplete="off">
                        <?php if (isset($errors) && $errors->has('start_number')) { ?>
                            <p class="error"><?php echo $errors->first('start_number') ?></p>
                        <?php } ?>
                    </td>
                </tr>
                <tr class="form-field <?php echo (isset($errors) && $errors->has('ask_name')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="ask_name">
                            <?php esc_html_e('Ask Name', 'jltoken') ?>
                        </label>
                    </th>
                    <td>
                        <select name="ask_name" id="ask_name">
                            <option value="1" <?php echo (intval(Utility::issetValueOld($service, 'ask_name')) === 1) ? 'selected' : '' ?>><?php esc_html_e('Yes', 'jltoken') ?></option>
                            <option value="0" <?php echo (intval(Utility::issetValueOld($service, 'ask_name')) === 0) ? 'selected' : '' ?>><?php esc_html_e('No', 'jltoken') ?></option>
                        </select>
                        <?php if (isset($errors) && $errors->has('ask_name')) { ?>
                            <p class="error"><?php echo $errors->first('ask_name') ?></p>
                        <?php } ?>
                    </td>
                </tr>
                <tr class="form-field <?php echo (isset($errors) && $errors->has('name_required')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="name_required">
                            <?php esc_html_e('Name Required', 'jltoken') ?>
                        </label>
                    </th>
                    <td>
                        <select name="name_required" id="name_required" <?php echo (intval(Utility::issetValueOld($service, 'ask_name')) === 0) ? 'disabled' : '' ?>>
                            <option value="1" <?php echo (intval(Utility::issetValueOld($service, 'name_required')) === 1) ? 'selected' : '' ?>><?php esc_html_e('Yes', 'jltoken') ?></option>
                            <option value="0" <?php echo (intval(Utility::issetValueOld($service, 'name_required')) === 0) ? 'selected' : '' ?>><?php esc_html_e('No', 'jltoken') ?></option>
                        </select>
                        <?php if (isset($errors) && $errors->has('name_required')) { ?>
                            <p class="error"><?php echo $errors->first('name_required') ?></p>
                        <?php } ?>
                    </td>
                </tr>
                <tr class="form-field <?php echo (isset($errors) && $errors->has('ask_email')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="ask_email">
                            <?php esc_html_e('Ask Email', 'jltoken') ?>
                        </label>
                    </th>
                    <td>
                        <select name="ask_email" id="ask_email">
                            <option value="1" <?php echo (intval(Utility::issetValueOld($service, 'ask_email')) === 1) ? 'selected' : '' ?>><?php esc_html_e('Yes', 'jltoken') ?></option>
                            <option value="0" <?php echo (intval(Utility::issetValueOld($service, 'ask_email')) === 0) ? 'selected' : '' ?>><?php esc_html_e('No', 'jltoken') ?></option>
                        </select>
                        <?php if (isset($errors) && $errors->has('ask_email')) { ?>
                            <p class="error"><?php echo $errors->first('ask_email') ?></p>
                        <?php } ?>
                    </td>
                </tr>
                <tr class="form-field <?php echo (isset($errors) && $errors->has('email_required')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="email_required">
                            <?php esc_html_e('Email Required', 'jltoken') ?>
                        </label>
                    </th>
                    <td>
                        <select name="email_required" id="email_required" <?php echo (intval(Utility::issetValueOld($service, 'ask_email')) === 0) ? 'disabled' : '' ?>>
                            <option value="1" <?php echo (intval(Utility::issetValueOld($service, 'email_required')) === 1) ? 'selected' : '' ?>><?php esc_html_e('Yes', 'jltoken') ?></option>
                            <option value="0" <?php echo (intval(Utility::issetValueOld($service, 'email_required')) === 0) ? 'selected' : '' ?>><?php esc_html_e('No', 'jltoken') ?></option>
                        </select>
                        <?php if (isset($errors) && $errors->has('email_required')) { ?>
                            <p class="error"><?php echo $errors->first('email_required') ?></p>
                        <?php } ?>
                    </td>
                </tr>
                <tr class="form-field <?php echo (isset($errors) && $errors->has('ask_phone')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="ask_phone">
                            <?php esc_html_e('Ask Phone', 'jltoken') ?>
                        </label>
                    </th>
                    <td>
                        <select name="ask_phone" id="ask_phone">
                            <option value="1" <?php echo (intval(Utility::issetValueOld($service, 'ask_phone')) === 1) ? 'selected' : '' ?>><?php esc_html_e('Yes', 'jltoken') ?></option>
                            <option value="0" <?php echo (intval(Utility::issetValueOld($service, 'ask_phone')) === 0) ? 'selected' : '' ?>><?php esc_html_e('No', 'jltoken') ?></option>
                        </select>
                        <?php if (isset($errors) && $errors->has('ask_phone')) { ?>
                            <p class="error"><?php echo $errors->first('ask_phone') ?></p>
                        <?php } ?>
                    </td>
                </tr>
                <tr class="form-field <?php echo (isset($errors) && $errors->has('phone_required')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="phone_required">
                            <?php esc_html_e('Phone Required', 'jltoken') ?>
                        </label>
                    </th>
                    <td>
                        <select name="phone_required" id="phone_required" <?php echo (intval(Utility::issetValueOld($service, 'ask_phone')) === 0) ? 'disabled' : '' ?>>
                            <option value="1" <?php echo (intval(Utility::issetValueOld($service, 'phone_required')) === 1) ? 'selected' : '' ?>><?php esc_html_e('Yes', 'jltoken') ?></option>
                            <option value="0" <?php echo (intval(Utility::issetValueOld($service, 'phone_required')) === 0) ? 'selected' : '' ?>><?php esc_html_e('No', 'jltoken') ?></option>
                        </select>
                        <?php if (isset($errors) && $errors->has('phone_required')) { ?>
                            <p class="error"><?php echo $errors->first('phone_required') ?></p>
                        <?php } ?>
                    </td>
                </tr>
                <tr class="form-field form-required <?php echo (isset($errors) && $errors->has('status')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="status">
                            <?php esc_html_e('Status', 'jltoken') ?>
                            <span class="description">(<?php esc_html_e('required', 'jltoken') ?>)</span>
                        </label>
                    </th>
                    <td>
                        <select name="status" id="status">
                            <option value="1" <?php echo (intval(Utility::issetValueOld($service, 'status')) === 1) ? 'selected' : '' ?>><?php esc_html_e('Enable', 'jltoken') ?></option>
                            <option value="0" <?php echo (intval(Utility::issetValueOld($service, 'status')) === 0) ? 'selected' : '' ?>><?php esc_html_e('Disable', 'jltoken') ?></option>
                        </select>
                        <?php if (isset($errors) && $errors->has('status')) { ?>
                            <p class="error"><?php echo $errors->first('status') ?></p>
                        <?php } ?>
                    </td>
                </tr>
            </tbody>
        </table>
        <p class="submit">
            <input type="submit" class="button button-primary" value="<?php Utility::issetValue($service) ? esc_html_e('Update Service', 'jltoken') : esc_html_e('Add Service', 'jltoken') ?>">
        </p>
    </form>
</div>