<?php

use IgniteKit\Validation\ErrorBag;
use Justlab\JLToken\Utility;

if (!function_exists('add_action') || !defined('ABSPATH')) {
    echo "Hi there! I'm just a plugin, not much I can do when called directly.";
    exit;
}
?>
<div class="wrap">

    <h1 id="wp-heading-inline">
        <?php esc_html_e('Settings', 'jltoken') ?>
    </h1>
    <?php
    if (isset($result) && $result && !($result instanceof ErrorBag)) {
        Utility::notice(esc_html__('Settings updated successfully!', 'jltoken'));
        if (!Utility::issetValue($settings)) {
            $_POST = [];
        }
    } else if (isset($result) && (($result instanceof ErrorBag) || !$result)) {
        Utility::notice(esc_html__('Something went wrong. Please try again', 'jltoken'), 'e');
    }
    ?>
    <p><?php esc_html_e('Update JL Token Settings', 'jltoken') ?></p>
    <form method="post">
        <?php wp_nonce_field('jltoken-settings') ?>
        <table class="form-table" role="presentation">
            <tbody>
                <tr class="form-field <?php echo (isset($errors) && $errors->has('notification')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="notification">
                            <?php esc_html_e('Notification', 'jltoken') ?>
                        </label>
                    </th>
                    <td>
                        <input name="notification" type="text" id="notification" value="<?php echo Utility::issetValueOld($settings, 'notification') ?>" aria-required="true" autocorrect="off" autocomplete="off" maxlength="60">
                        <?php if (isset($errors) && $errors->has('notification')) { ?>
                            <p class="error"><?php echo $errors->first('notification') ?></p>
                        <?php } ?>
                    </td>
                </tr>
                <tr class="form-field <?php echo (isset($errors) && $errors->has('font_size')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="font_size">
                            <?php esc_html_e('Notification font size', 'jltoken') ?>
                        </label>
                    </th>
                    <td>
                        <input name="font_size" type="number" id="font_size" value="<?php echo Utility::issetValueOld($settings, 'font_size') ?>" aria-required="true" autocorrect="off" autocomplete="off" maxlength="2">
                        <?php if (isset($errors) && $errors->has('font_size')) { ?>
                            <p class="error"><?php echo $errors->first('font_size') ?></p>
                        <?php } ?>
                    </td>
                </tr>
                <tr class="form-field <?php echo (isset($errors) && $errors->has('font_color')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="font_color">
                            <?php esc_html_e('Notification color', 'jltoken') ?>
                        </label>
                    </th>
                    <td>
                        <input name="font_color" type="text" id="font_color" value="<?php echo Utility::issetValueOld($settings, 'font_color') ?>" aria-required="true" autocorrect="off" autocomplete="off">
                        <?php if (isset($errors) && $errors->has('font_color')) { ?>
                            <p class="error"><?php echo $errors->first('font_color') ?></p>
                        <?php } ?>
                    </td>
                </tr>
                <tr class="form-field form-required <?php echo (isset($errors) && $errors->has('voice_id')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="voice_id">
                            <?php esc_html_e('Display Voice', 'jltoken') ?>
                            <span class="description">(<?php esc_html_e('required', 'jltoken') ?>)</span>
                        </label>
                    </th>
                    <td>
                        <select name="voice_id" id="voice_id">
                            <?php foreach ($voices as $voice) { ?>
                                <option value="<?php echo $voice->id ?>" <?php echo (intval(Utility::issetValueOld($settings, 'voice_id')) == $voice->id) ? 'selected' : '' ?>><?php echo $voice->native_name ?></option>
                            <?php } ?>
                        </select>
                        <?php if (isset($errors) && $errors->has('voice_id')) { ?>
                            <p class="error"><?php echo $errors->first('voice_id') ?></p>
                        <?php } ?>
                    </td>
                </tr>
                <tr class="form-field form-required <?php echo (isset($errors) && $errors->has('show_on_display')) ? 'form-invalid' : '' ?>">
                    <th scope="row">
                        <label for="show_on_display">
                            <?php esc_html_e('Show on Display', 'jltoken') ?>
                            <span class="description">(<?php esc_html_e('required', 'jltoken') ?>)</span>
                        </label>
                    </th>
                    <td>
                        <select name="show_on_display" id="show_on_display">
                            <option value=""><?php esc_html_e('None', 'jltoken') ?></option>
                            <option value="name" <?php echo (Utility::issetValueOld($settings, 'show_on_display') == 'name') ? 'selected' : '' ?>><?php esc_html_e('Name', 'jltoken') ?></option>
                            <option value="email" <?php echo (Utility::issetValueOld($settings, 'show_on_display') == 'email') ? 'selected' : '' ?>><?php esc_html_e('Email', 'jltoken') ?></option>
                            <option value="phone" <?php echo (Utility::issetValueOld($settings, 'show_on_display') == 'phone') ? 'selected' : '' ?>><?php esc_html_e('Phone', 'jltoken') ?></option>
                        </select>
                        <?php if (isset($errors) && $errors->has('show_on_display')) { ?>
                            <p class="error"><?php echo $errors->first('show_on_display') ?></p>
                        <?php } ?>
                    </td>
                </tr>
            </tbody>
        </table>
        <p class="submit">
            <input type="submit" class="button button-primary" value="<?php esc_html_e('Update Settings', 'jltoken') ?>">
        </p>
        <p>
        <h3><?php esc_html_e('Notification Preview', 'jltoken') ?></h3>
        </p>
        <marquee class="settings-marquee"><span style="font-size:<?php echo $settings->font_size ?>px;color:<?php echo $settings->font_color ?>"><?php echo $settings->notification ?></span></marquee>
    </form>
</div>